#!/usr/bin/env bash

WRF_FirstUser=`pwd`
lib_wrf=$WRF_FirstUser/lib_wrf

mkdir $lib_wrf

cd $lib_wrf

echo '%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%'
echo 'msg: Install library WRF'
echo '%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%'
sudo apt-get install csh
sudo apt-get install gfortran
sudo apt-get install m4
sudo apt-get install mpich
sudo apt-get install libhdf5-mpich-dev
#sudo apt-get install libpng-dev
#sudo apt-get install libnetcdff-dev
#sudo apt-get install netcdf-bin
sudo apt-get install ncl-ncarg
#sudo apt-get install grads
sudo apt-get install wget
sudo apt-get install make
sudo apt-get install build-essential

#Jasper
wget http://www.ece.uvic.ca/~frodo/jasper/software/jasper-1.900.19.tar.gz
tar -zxvf jasper-1.900.19.tar.gz
cd jasper-1.900.19
./configure --prefix=$lib_wrf
make
make install
rm -r jasper-1.900.19*
cd $lib_wrf

#zlib
wget http://zlib.net/zlib-1.2.8.tar.gz
tar -zxvf zlib-1.2.8.tar.gz
cd zlib-1.2.8
./configure --prefix=$lib_wrf
make
make install
rm -r zlib-1.2.8*
cd $lib_wrf

#libpng
wget http://prdownloads.sourceforge.net/libpng/libpng-1.6.26.tar.gz
tar -zxvf libpng-1.6.26.tar.gz
cd libpng-1.6.26
./configure --prefix=$lib_wrf
make
make install
rm -r libpng-1.6.26*
cd $lib_wrf

#netcdf
wget ftp://ftp.unidata.ucar.edu/pub/netcdf/netcdf-3.6.3.tar.gz
tar -zxvf netcdf-3.6.3.tar.gz
cd netcdf-3.6.3
./configure --prefix=$lib_wrf/netcdf FC=gfortran F77=gfortran F90=gfortran CC=gcc CXX= 
make
make install
rm -r netcdf-3.6.3*
cd $lib_wrf

#openmpi
wget https://www.open-mpi.org/software/ompi/v2.0/downloads/openmpi-2.0.1.tar.gz
tar -zxvf openmpi-2.0.1.tar.gz
cd openmpi-2.0.1
./configure --prefix=$lib_wrf/openmpi FC=gfortran F77=gfortran F90=gfortran CC=gcc CXX= 
make
make install
rm -r openmpi-2.0.1*
cd $lib_wrf

#GRADS
wget http://downloads.sourceforge.net/project/opengrads/grads2/2.0.2.oga.1/Linux/grads-2.0.2.oga.1-bundle-x86_64-unknown-linux-gnu.tar.gz 
tar -zxvf grads-2.0.2.oga.1-bundle-x86_64-unknown-linux-gnu.tar.gz

echo '#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%' >> $HOME/.bashrc
echo '#msg: Library WRF' >> $HOME/.bashrc
echo '#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%' >> $HOME/.bashrc
echo 'NETCDF='$lib_wrf'/netcdf' >> $HOME/.bashrc
echo 'OPENMPI='$lib_wrf'/openmpi' >> $HOME/.bashrc
echo 'PATH=$PATH:$NETCDF/bin:$OPENMPI/bin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin' >> $HOME/.bashrc 
echo 'PATH=$PATH:'$lib_wrf'/grads-2.0.2.oga.1/Contents' >> $HOME/.bashrc
echo 'LD_LIBRARY_PATH=$LD_LIBRARY_PATH:'$lib_wrf'/lib:$NETCDF/lib:$OPENMPI/lib' >> $HOME/.bashrc
echo 'LD_INLCUDE_PATH=$LD_INLCUDE_PATH:$NETCDF/include' >> $HOME/.bashrc
echo 'GADDIR='$lib_wrf'/grads-2.0.2.oga.1/Contents/Resources/SupportData' >> $HOME/.bashrc
echo 'GASCRP=$GADDIR' >> $HOME/.bashrc
echo 'export NETCDF PATH LD_INLCUDE_PATH LD_LIBRARY_PATH GADDIR GASCRP' >> $HOME/.bashrc

cd $HOME
source .bashrc

echo '%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%'
echo 'msg: Downloads input data WRF'
echo '%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%'
cd $WRF_FirstUser
wget http://www2.mmm.ucar.edu/wrf/src/wps_files/geog.tar.gz
tar -zxvf geog.tar.gz
rm geog.tar.gz

wget http://www.icat.ufal.br/laboratorio/modelagem_atmosferica/downloads/input_fnl.tar.gz
tar -zxvf input_fnl.tar.gz
rm input_fnl.tar.gz

wget http://www.icat.ufal.br/laboratorio/modelagem_atmosferica/downloads/wrf_tree.tar.gz
tar -zxvf wrf_tree.tar.gz
rm wrf_tree.tar.gz
echo '%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%'
echo 'msg: Finish configuration'
echo '%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%'


